@@ -3,19 +3,20 @@
    Copyright (C) 2002-2007 Bas Wijnen <shevek@fmf.nl>
    Copyright (C) 2005 Jan Wilmans <jw@dds.nl>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License
-   as published by the Free Software Foundation; either version 2
-   of the License, or (at your option) any later version.
+   This file is part of z80asm.
 
-   This program is distributed in the hope that it will be useful,
+   Z80asm is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
+
+   Z80asm is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License along
-   with this program; if not, write to the Free Software Foundation, Inc.,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef Z80ASM_H
@@ -158,6 +159,8 @@ struct reference
   int done;			/* if this reference has been computed */
   int computed_value;		/* value (only valid if done = true) */
   int level;			/* maximum stack level of labels to use */
+  struct includedir *dir;	/* dirname of file (for error reporting) */
+  char *file;			/* filename (for error reporting) */
   char input[1];		/* variable size buffer containing formula */
 };
 
